WrapLayoutConfig class final

Inheritance

Constructors

WrapLayoutConfig({Axis axis = Axis.horizontal, double spacing = 0, double runSpacing = 0})
const

Properties

axis Axis
final
hashCode int
The hash code for this object.
no setterinherited
runSpacing double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited